CallBuilder

Struct CallBuilder 

pub struct CallBuilder { /* private fields */ }
Builder for configuring a function call within a transaction.

Created via TransactionBuilder::call. Allows setting args, gas, and deposit before continuing to chain more actions or sending.

Implementations

Source

impl CallBuilder

pub fn args<A: Serialize>(self, args: A) -> Self

Set JSON arguments.

pub fn args_raw(self, args: Vec<u8>) -> Self

Set raw byte arguments.

pub fn args_borsh<A: BorshSerialize>(self, args: A) -> Self

Set Borsh-encoded arguments.

pub fn gas(self, gas: impl IntoGas) -> Self

Set gas limit.

Example
near.transaction("contract.testnet")
    .call("method")
        .gas(Gas::tgas(50))
    .send()
    .await?;
Panics

Panics if the gas string cannot be parsed. Use Gas’s FromStr impl for fallible parsing of user input.

pub fn deposit(self, amount: impl IntoNearToken) -> Self

Set attached deposit.

Example
near.transaction("contract.testnet")
    .call("method")
        .deposit(NearToken::near(1))
    .send()
    .await?;
Panics

Panics if the amount string cannot be parsed. Use NearToken’s FromStr impl for fallible parsing of user input.

pub fn call(self, method: &str) -> CallBuilder

Add another function call.

pub fn create_account(self) -> TransactionBuilder

Add a create account action.

pub fn transfer(self, amount: impl IntoNearToken) -> TransactionBuilder

Add a transfer action.

pub fn deploy(self, code: impl Into<Vec<u8>>) -> TransactionBuilder

Add a deploy contract action.

pub fn add_full_access_key(self, public_key: PublicKey) -> TransactionBuilder

Add a full access key.

pub fn add_function_call_key( self, public_key: PublicKey, receiver_id: impl AsRef<str>, method_names: Vec<String>, allowance: Option<NearToken>, ) -> TransactionBuilder

Add a function call access key.

pub fn delete_key(self, public_key: PublicKey) -> TransactionBuilder

Delete an access key.

pub fn delete_account( self, beneficiary_id: impl AsRef<str>, ) -> TransactionBuilder

Delete the account.

pub fn stake( self, amount: impl IntoNearToken, public_key: PublicKey, ) -> TransactionBuilder

Add a stake action.

pub fn publish_contract( self, code: impl Into<Vec<u8>>, by_hash: bool, ) -> TransactionBuilder

Publish a contract to the global registry.

pub fn deploy_from_hash(self, code_hash: CryptoHash) -> TransactionBuilder

Deploy a contract from the global registry by code hash.

pub fn deploy_from_publisher( self, publisher_id: impl AsRef<str>, ) -> TransactionBuilder

Deploy a contract from the global registry by publisher account.

pub fn state_init_by_hash( self, code_hash: CryptoHash, data: BTreeMap<Vec<u8>, Vec<u8>>, deposit: impl IntoNearToken, ) -> TransactionBuilder

Create a NEP-616 deterministic state init action with code hash reference.

pub fn state_init_by_publisher( self, publisher_id: impl AsRef<str>, data: BTreeMap<Vec<u8>, Vec<u8>>, deposit: impl IntoNearToken, ) -> TransactionBuilder

Create a NEP-616 deterministic state init action with publisher account reference.

pub fn sign_with(self, signer: impl Signer + 'static) -> TransactionBuilder

Override the signer.

pub fn wait_until(self, status: TxExecutionStatus) -> TransactionBuilder

Set the execution wait level.

pub async fn delegate( self, options: DelegateOptions, ) -> Result<DelegateResult, Error>

Build and sign a delegate action for meta-transactions (NEP-366).

This finishes the current function call and then creates a delegate action.

pub async fn sign_offline( self, block_hash: CryptoHash, nonce: u64, ) -> Result<SignedTransaction, Error>

Sign the transaction offline without network access.

See TransactionBuilder::sign_offline for details.

pub async fn sign(self) -> Result<SignedTransaction, Error>

Sign the transaction without sending it.

See TransactionBuilder::sign for details.

pub fn send(self) -> TransactionSend

Send the transaction.