RpcError

Enum RpcError 

pub enum RpcError {
Show 28 variants Http(Error), Network { message: String, status_code: Option<u16>, retryable: bool, }, Timeout(u32), Json(Error), InvalidResponse(String), Rpc { code: i64, message: String, data: Option<Value>, }, AccountNotFound(AccountId), InvalidAccount(String), AccessKeyNotFound { account_id: AccountId, public_key: PublicKey, }, ContractNotDeployed(AccountId), ContractStateTooLarge(AccountId), ContractExecution { contract_id: AccountId, method_name: Option<String>, message: String, }, ContractPanic { message: String, }, FunctionCall { contract_id: AccountId, method_name: String, panic: Option<String>, logs: Vec<String>, }, UnknownBlock(String), UnknownChunk(String), UnknownEpoch(String), InvalidShardId(String), UnknownReceipt(String), InvalidTransaction { message: String, details: Option<Value>, shard_congested: bool, shard_stuck: bool, }, InvalidNonce { tx_nonce: u64, ak_nonce: u64, }, InsufficientBalance { required: String, available: String, }, GasLimitExceeded { gas_used: String, gas_limit: String, }, ShardUnavailable(String), NodeNotSynced(String), InternalError(String), ParseError(String), RequestTimeout { message: String, transaction_hash: Option<String>, },
}
RPC-specific errors.

Variants



Http(Error)



Network

Fields

message: String
status_code: Option<u16>
retryable: bool


Timeout(u32)



Json(Error)



InvalidResponse(String)



Rpc

Fields

code: i64
message: String


AccountNotFound(AccountId)



InvalidAccount(String)



AccessKeyNotFound

Fields

account_id: AccountId
public_key: PublicKey


ContractNotDeployed(AccountId)



ContractStateTooLarge(AccountId)



ContractExecution

Fields

contract_id: AccountId
method_name: Option<String>
message: String


ContractPanic

Fields

message: String


FunctionCall

Fields

contract_id: AccountId
method_name: String
logs: Vec<String>


UnknownBlock(String)



UnknownChunk(String)



UnknownEpoch(String)



InvalidShardId(String)



UnknownReceipt(String)



InvalidTransaction

Fields

message: String
details: Option<Value>
shard_congested: bool
shard_stuck: bool


InvalidNonce

Fields

tx_nonce: u64
ak_nonce: u64


InsufficientBalance

Fields

required: String
available: String


GasLimitExceeded

Fields

gas_used: String
gas_limit: String


ShardUnavailable(String)



NodeNotSynced(String)



InternalError(String)



ParseError(String)



RequestTimeout

Fields

message: String
transaction_hash: Option<String>

Implementations

Source

impl RpcError

pub fn is_retryable(&self) -> bool

Check if this error is retryable.

pub fn network( message: impl Into<String>, status_code: Option<u16>, retryable: bool, ) -> Self

Create a network error.

pub fn invalid_transaction( message: impl Into<String>, details: Option<Value>, ) -> Self

Create an invalid transaction error.

pub fn function_call( contract_id: AccountId, method_name: impl Into<String>, panic: Option<String>, logs: Vec<String>, ) -> Self

Create a function call error.

Source

impl RpcError

Main error type for near-kit operations.

pub fn is_account_not_found(&self) -> bool

Returns true if this error indicates the account was not found.

pub fn is_contract_not_deployed(&self) -> bool

Returns true if this error indicates a contract is not deployed.