pub struct VerifyOptions {
pub max_age: Duration,
pub require_full_access: bool,
}Expand description
Options for signature verification.
Fields
max_age: DurationMaximum age for the signature to be considered valid.
Set to Duration::MAX to disable expiration checking.
Default: 5 minutes.
require_full_access: boolWhether to verify that the public key belongs to the account and has full access permission via RPC. Default: true.