pub struct NonDelegateAction(/* private fields */);Expand description
Non-delegate action (for use within DelegateAction).
This is a newtype wrapper around Action that ensures the wrapped action is not a Delegate variant, since delegate actions cannot contain nested delegate actions.
The newtype wrapper serializes identically to the inner Action, preserving Borsh compatibility with near-primitives.
Implementations
Sourceimpl NonDelegateAction
impl NonDelegateAction
Sourcepub fn from_action(action: Action) -> Option<Self>
pub fn from_action(action: Action) -> Option<Self>
Convert from an Action, returning None if it’s a Delegate action.
Sourcepub fn into_inner(self) -> Action
pub fn into_inner(self) -> Action
Consume self and return the inner action.