SignedDelegateAction

Struct SignedDelegateAction 

pub struct SignedDelegateAction {
    pub delegate_action: DelegateAction,
    pub signature: Signature,
}
Signed delegate action.

Fields

delegate_action: DelegateAction

The delegate action.

signature: Signature

Signature over the delegate action.

Implementations

Source

impl SignedDelegateAction

pub fn to_bytes(&self) -> Vec<u8>

Encode the signed delegate action to bytes for transport.

pub fn to_base64(&self) -> String

Encode the signed delegate action to base64 for transport.

This is the most common format for sending delegate actions via HTTP/JSON.

pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>

Decode a signed delegate action from bytes.

pub fn from_base64(s: &str) -> Result<Self, DecodeError>

Decode a signed delegate action from base64.

pub fn sender_id(&self) -> &AccountId

Get the sender account ID.

pub fn receiver_id(&self) -> &AccountId

Get the receiver account ID.