SignedTransaction

Struct SignedTransaction 

pub struct SignedTransaction {
    pub transaction: Transaction,
    pub signature: Signature,
}
A signed transaction ready to be sent.

Fields

transaction: Transaction

The unsigned transaction.

signature: Signature

The signature.

Implementations

Source

impl SignedTransaction

pub fn get_hash(&self) -> CryptoHash

Get the hash of the signed transaction (transaction hash).

pub fn to_bytes(&self) -> Vec<u8>

Serialize to bytes for RPC submission.

pub fn to_base64(&self) -> String

Serialize to base64 for RPC submission.

pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>

Deserialize from bytes.

Use this to reconstruct a signed transaction that was serialized with to_bytes.

Example
use near_kit::SignedTransaction;
let bytes: Vec<u8> = /* received from offline signer */;
let signed_tx = SignedTransaction::from_bytes(&bytes)?;
pub fn from_base64(s: &str) -> Result<Self, Error>

Deserialize from base64.

Use this to reconstruct a signed transaction that was serialized with to_base64.

Example
let base64_str = "AgAAAGFsaWNlLnRlc3RuZXQ...";
let signed_tx = SignedTransaction::from_base64(base64_str)?;