GlobalContractRef

Trait GlobalContractRef 

pub trait GlobalContractRef {
    // Required method
    fn into_identifier(self) -> GlobalContractIdentifier;
}
Trait for types that can identify a global contract.

This allows deploy_from to accept either a CryptoHash (for immutable contracts) or an account ID string/AccountId (for publisher-updatable contracts).

Panics

String-based implementations (&str, String, &String) panic if the string is not a valid NEAR account ID.

Required Methods

Implementations on Foreign Types

Source

impl GlobalContractRef for &str

Source

impl GlobalContractRef for &String

Source

impl GlobalContractRef for String

Implementors