WaitLevel

Trait WaitLevel 

pub trait WaitLevel:
    Sealed
    + Send
    + Sync
    + 'static {
    type Response: Send + 'static;

    // Required method
    fn status() -> TxExecutionStatus;
}
Trait for type-safe transaction wait levels.

Each wait level is a zero-sized marker type that carries:

This trait is sealed and cannot be implemented outside this crate.

Required Associated Types

type Response: Send + 'static

The type returned when awaiting a transaction with this wait level.

Required Methods

fn status() -> TxExecutionStatus

The RPC wait_until value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors